.. currentmodule:: pysdic.geometry

pysdic.geometry.IntegratedPoints
===========================================

.. autoclass:: IntegratedPoints


Accessing IntegratedPoints attributes
-------------------------------------------

.. autosummary::
   :toctree: ../generated/

    IntegratedPoints.element_indices
    IntegratedPoints.internal_bypass
    IntegratedPoints.n_dimensions
    IntegratedPoints.n_points
    IntegratedPoints.n_valids
    IntegratedPoints.natural_coordinates
    IntegratedPoints.shape
    IntegratedPoints.weights

Manipulating IntegratedPoints objects
-------------------------------------------

.. autosummary::
   :toctree: ../generated/

    IntegratedPoints.add_points
    IntegratedPoints.copy
    IntegratedPoints.disable_points
    IntegratedPoints.remove_invalids
    IntegratedPoints.remove_points
    IntegratedPoints.validate

